==> haskell-memory-0.14.11-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: memory
version: 0.14.11
id: memory-0.14.11-3SpbaRkSFfh8uo9jYloypK
key: memory-0.14.11-3SpbaRkSFfh8uo9jYloypK
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>
stability: experimental
homepage: https://github.com/vincenthz/hs-memory
synopsis: memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation
    .
    * A polymorphic byte array abstraction and function similar to strict ByteString.
    .
    * Different type of byte array abstraction.
    .
    * Raw memory IO operations (memory set, memory copy, ..)
    .
    * Aliasing with endianness support.
    .
    * Encoding : Base16, Base32, Base64.
    .
    * Hashing : FNV, SipHash
category: memory
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.Memory.Encoding.Base16 Data.Memory.Encoding.Base32
    Data.Memory.Encoding.Base64 Data.Memory.Endian
    Data.Memory.ExtendedWords Data.Memory.PtrMethods
hidden-modules: Data.Memory.Internal.Compat
                Data.Memory.Internal.CompatPrim Data.Memory.Internal.CompatPrim64
                Data.Memory.Internal.DeepSeq Data.Memory.Internal.Imports
                Data.Memory.Internal.Scrubber Data.Memory.Hash.SipHash
                Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
                Data.ByteArray.Types Data.ByteArray.Bytes
                Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
                Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix
abi: c6c4c617bf03bbd1c14846dd5fa74fd6
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.11
library-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.11
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/memory-0.14.11
hs-libraries: HSmemory-0.14.11-3SpbaRkSFfh8uo9jYloypK
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    basement-0.0.4-7pJikASNmAFFwadsMZ0ihV
    foundation-0.0.17-3EJrWR1TS4FLqlH4cEiNSC
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             basement-0.0.4-7pJikASNmAFFwadsMZ0ihV=71284c7f18b2b2dc2a5fd5dc4a6fd227
             foundation-0.0.17-3EJrWR1TS4FLqlH4cEiNSC=1830cbd1bcfa709c44fefba8a2c4ddb0
haddock-interfaces: /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html: /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-memory-0.14.16-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-memory.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: memory
version: 0.14.16
id: memory-0.14.16-JXoliazMy4LBu5xxL66kmR
key: memory-0.14.16-JXoliazMy4LBu5xxL66kmR
license: BSD3
copyright: Vincent Hanquez <vincent@snarc.org>
maintainer: vincent@snarc.org, Nicolas Di Prima <nicolas@primetype.co.uk>
stability: experimental
homepage: https://github.com/vincenthz/hs-memory
synopsis: memory and related abstraction stuff
description:
    Chunk of memory, polymorphic byte array management and manipulation
    .
    * A polymorphic byte array abstraction and function similar to strict ByteString.
    .
    * Different type of byte array abstraction.
    .
    * Raw memory IO operations (memory set, memory copy, ..)
    .
    * Aliasing with endianness support.
    .
    * Encoding : Base16, Base32, Base64.
    .
    * Hashing : FNV, SipHash
category: memory
author: Vincent Hanquez <vincent@snarc.org>
exposed: True
indefinite: False
exposed-modules:
    Data.ByteArray Data.ByteArray.Encoding Data.ByteArray.Hash
    Data.ByteArray.Mapping Data.ByteArray.Pack Data.ByteArray.Parse
    Data.ByteArray.Sized Data.Memory.Encoding.Base16
    Data.Memory.Encoding.Base32 Data.Memory.Encoding.Base64
    Data.Memory.Endian Data.Memory.ExtendedWords Data.Memory.PtrMethods
hidden-modules: Data.Memory.Internal.Compat
                Data.Memory.Internal.CompatPrim Data.Memory.Internal.CompatPrim64
                Data.Memory.Internal.DeepSeq Data.Memory.Internal.Imports
                Data.Memory.Internal.Scrubber Data.Memory.Hash.SipHash
                Data.Memory.Hash.FNV Data.ByteArray.Pack.Internal
                Data.ByteArray.Types Data.ByteArray.Bytes
                Data.ByteArray.ScrubbedBytes Data.ByteArray.Methods
                Data.ByteArray.MemView Data.ByteArray.View Data.Memory.MemMap.Posix
abi: ab65a51ef395f4cd2a78138a2eaca54b
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.16
library-dirs: /usr/lib/ghc-8.2.2/site-local/memory-0.14.16
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/memory-0.14.16
hs-libraries: HSmemory-0.14.16-JXoliazMy4LBu5xxL66kmR
depends:
    base-4.10.1.0 ghc-prim-0.5.1.1 bytestring-0.10.8.2 deepseq-1.4.3.0
    basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc
    foundation-0.0.20-LDsWRO4CnfkCvH9X8EQgpn
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             ghc-prim-0.5.1.1=c8f3d173544d1472727fce7b0518abda
             bytestring-0.10.8.2=4a9e2cf748f0e2cc5be33be7a5505ecf
             deepseq-1.4.3.0=38379f7f81eed7fe046dd2a98559af2e
             basement-0.0.7-IRcTCDmYoctGxt4FUYqdQc=77aa457f5c07dcb3edd04711d3590241
             foundation-0.0.20-LDsWRO4CnfkCvH9X8EQgpn=c13ddef7a61485e65af46709a1c70219
haddock-interfaces: /usr/share/doc/haskell-memory/html/memory.haddock
haddock-html: /usr/share/doc/haskell-memory/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
